;Mario Bros Sound Code

	ORG	$2200									;TO $27FF

;	TUNE VARIABLES - $34 BYTES
TUNEAREA		EQU	$2200
TUNESOFF		EQU	TUNEAREA+$0000				;1 BYTE  - FLAG FOR ALL TUNES OFF
TUNNUM			EQU	TUNEAREA+$0001				;1 BYTE  - CURRENT TUNE NUMBER BEING PROCESSED
TUNCHANNEL		EQU	TUNEAREA+$0002				;1 BYTE  - CONVERTED FOR INDEX INTO POKEY CHANNEL REGISTERS
TUNFILLER		EQU	TUNEAREA+$0003				;1 BYTE  - NOT USED YET
TUNON			EQU	TUNEAREA+$0004				;4 BYTES - FLAG FOR TUNE PLAYING BY CHANNEL
NOTELO			EQU	TUNEAREA+$0008				;4 BYTES - INDEX INTO NOTE TABLE LOW
NOTEHI			EQU	TUNEAREA+$000C				;4 BYTES - INDEX INTO NOTE TABLE HI
CTLVOL			EQU	TUNEAREA+$0010				;4 BYTES - CONTROL / VOLUME VALUE BY CHANNEL
TUNINDEX		EQU	TUNEAREA+$0014				;4 BYTES - TUNE NUMBER BY CHANNEL
TUNFRM			EQU	TUNEAREA+$0018				;4 BYTES - NUMBER OF FRAMES (DURATION COUNT)
TUNPRIOR		EQU	TUNEAREA+$001C				;4 BYTES - TUNE PRIORITY BY CHANNEL
DURNLO			EQU	TUNEAREA+$0020				;4 BYTES - INDEX INTO DURATION TABLE LOW
DURNHI			EQU	TUNEAREA+$0024				;4 BYTES - INDEX INTO DURATION TABLE HI
DCYSTOR			EQU	TUNEAREA+$0028				;4 BYTES - FOR NOTE DECAY BY CHANNEL
FREQCNT			EQU	TUNEAREA+$002C				;4 BYTES - FOR NOTE DECAY BY CHANNEL
CTLSAV			EQU	TUNEAREA+$0030				;4 BYTES - TO SAVE THE CONTROL VALUE

	org $2240

;	SOUND -------------------------------------------------------------------------------------------------------------------->

;	TUNES - THESE ROUTINES HANDLE ALL OF THE SOUNDS

;	RESET POKEY CHIP
RSTPOKEY:
	LDX #$0F 
	LDA #$00
RSTLP:
	STA AUDF0,X									;CLEAR POKEY REGISTERS
	DEX 
	BPL RSTLP 
	LDA #$03
	STA SKCTL	;S									;TURN IT ON
	RTS

;	TURN OFF ALL SOUNDS
STOPTUN
	LDA #$00
	STA AUDC0
	STA AUDC1
	STA AUDC2
	STA AUDC3
	LDA #$01
	STA TUNESOFF
	RTS

;	TURN ON ALL SOUNDS
STARTTUN
	LDA #$00
	STA TUNESOFF
	RTS

;	THIS ROUTINE ERASES ALL TUNES
;	X AND Y ARE PRESERVED
CLEARTUN
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDX #$03
CTLOOP
	JSR ENDTUNE									;ERASE CURRENT TUNE
	DEX
	BPL CTLOOP
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;	ROUTINE TO KILL A PARTICULAR TUNE - IF IT IS RUNNING
;	INPUT: TUNE NUMBER IN A
;	X AND Y ARE PRESERVED
KILLTUNE
	STA TUNNUM									;SAVE IT
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDX #$03									;CHECK ALL CHANNELS
KTLOOP
	LDA TUNON,X									;SEE IF CHANNEL ON
	BEQ KTNEXT
	LDA TUNINDEX,X								;SEE IF HAS TUNE TO BE KILLED
	CMP TUNNUM
	BNE KTNEXT
	JSR ENDTUNE									;ERASE IT
KTNEXT
	DEX
	BPL KTLOOP
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;	THIS ROUTINE CLEARS OUT A TUNE CHANNEL
;	INPUT: X IS CHANNEL
ENDTUNE
	LDA #$00
	STA TUNON,X									;INDICATE CHANNEL CLEAR
	STA TUNINDEX,X								;CLEAR TUNE INDEX
	STA DCYSTOR,X
	STA FREQCNT,X
	RTS

;	THIS ROUTINE ENTERS A TUNE INTO ONE OF THE SOUND CHANNELS IF IT CAN
;	INPUT:  TUNE NUMBER IN A
;	X AND Y ARE PRESERVED
DOTUNE
	STA TUNNUM									;SAVE IT
	;LDA AUTOPLAY								;IF IN AUTOPLAY - NO SOUND
	;BEQ DTCONT
	;RTS
DTCONT
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDY TUNNUM									;SEE IF WE CAN PUT IT IN
	LDX CHANNLTBL,Y								;GET WHAT CHANNEL TO TRY TO PUT IT IN
	LDA TUNON,X									;SEE IF CHANNEL OPEN
	BEQ DTDOIT
	LDA PRIRTYTBL,Y								;SEE IF WE CAN BUMP CHANNEL
	CMP TUNPRIOR,X
	BMI DTOUT
DTDOIT
	LDA TUNNUM
	TAY											;PUT TUNE IN Y
	STA TUNINDEX,X								;SET THE TUNE INDEX
	LDA #$00									;TURN TUNE OFF WHILE CHANGING IT
	STA TUNON,X
	LDA CNTVOLTBL,Y								;GET TUNE CONTROL / VOLUME
	STA CTLVOL,X
	STA CTLSAV,X								;USED TO RESTORE AFTER DECAY
	LDA NOTETBLLO,Y								;GET TUNE FREQUENCY LOW ADDRESS
	STA NOTELO,X
	LDA NOTETBLHI,Y								;GET TUNE FREQUENCY HIGH ADDRESS
	STA NOTEHI,X
	LDA DURNTBLLO,Y								;GET TUNE DURATION LOW ADDRESS
	STA DURNLO,X
	LDA DURNTBLHI,Y								;GET TUNE DURATION HIGH ADDRESS
	STA DURNHI,X
	LDA PRIRTYTBL,Y								;SET PRIORITY
	STA TUNPRIOR,X
	LDA #$01									;SET FREQ, CTL, AND VOL TO BE SET
	STA TUNFRM,X
	STA TUNON,X									;AND TURN THE TUNE ON!
DTOUT
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;  THIS ROUTINE IS CALLED EVERY VBLANK TO TAKE CARE OF TUNES
;  REGISTERS ARE NOT SAVED
TUNER
	LDX #$03									;FOUR TUNES CHANNELS, START WITH LAST
	LDA TUNESOFF
	BEQ TUNLOOP
	RTS
TUNLOOP
	TXA
	ASL
	STA TUNCHANNEL								;CHANNELS ARE OFFSET 0, 2, 4, 6 IN THE POKEY
	TAY
	LDA TUNON,X
	BNE TUNBODY
	STA AUDC0,Y									;CHANNEL OFF - MAKE SURE VOLUME OFF
	JMP TUNNEXT
TUNBODY
	DEC TUNFRM,X								;SEE IF WE'RE DONE WITH THIS SOUND
	BEQ TUNFRMFRQ								;YES - GET NEXT NOTE / DURATION
	DEC FREQCNT,X                               ;REDUCE THE NUMBER OF FRAMES UNTIL NEXT DECAY
	BEQ DEC_VOLUME
	JMP TUNNEXT                                 ;IF WE AREN'T AT ZERO YET, DON'T DECAY

DEC_VOLUME
	LDA DCYSTOR,X                               ;RESET THE DECAY FOR THE NEXT COUNT
	STA FREQCNT,X

	LDA CTLVOL,X                                ;IF VOLUME ALREADY 0 DO NOT DECREMENT
	AND #$0F
	BEQ TUNNEXT
	
	DEC CTLVOL,X                                ;DECREMENT THE VOLUME
	LDA CTLVOL,X
	LDY TUNCHANNEL
	;AND MUTEMASK,Y
	STA AUDC0,Y
	JMP TUNNEXT                                 ;GO TO NEXT CHANNEL
TUNFRMFRQ
	LDA DURNLO,X								;GET THE CURRENT DURATION
	STA SOUNDZP
	LDA DURNHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	BEQ TUNEND									;$00 IN DURATION MEANS TUNE IS OVER
	STA TUNFRM,X
	TAY
	LDA DECAYTBL,Y								;GET THE CURRENT DECAY VALUE INDEXED BY NOTE
	STA DCYSTOR,X								;STORE IT HERE TO REFRESH THE COUNTER FOR THE NEXT DECAY
	STA FREQCNT,X								;ALSO STORE IT HERE FOR TUNER
	LDY TUNCHANNEL
	LDA CTLSAV,X
	STA CTLVOL,X								;RESTORE THE ORIGINAL CONTROL AND VOLUME FOR NEXT NOTE
	STA AUDC0,Y
	LDA NOTELO,X								;GET THE CURRENT FREQUENCY
	STA SOUNDZP
	LDA NOTEHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	LDY TUNCHANNEL
	STA AUDF0,Y
	INC NOTELO,X
	BNE TUNNEXTNOTE
	INC NOTEHI,X
TUNNEXTNOTE
	INC DURNLO,X
	BNE TUNNEXT
	INC DURNHI,X
TUNNEXT
	DEX
	CPX #$00
	BMI TUNEXIT
	JMP TUNLOOP
TUNEXIT
	RTS

TUNEND
	LDA NOTELO,X								;SEE IF WE SHOULD REPEAT
	STA SOUNDZP
	LDA NOTEHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	BMI TUNRESTART
	JSR ENDTUNE
	JMP TUNNEXT
TUNRESTART
	LDA TUNINDEX,X								;GET TUNE NUMBER
	TAY
	LDA CNTVOLTBL,Y								;GET TUNE CONTROL / VOLUME
	STA CTLVOL,X
	STA CTLSAV,X								;USED TO RESTORE AFTER DECAY
	LDA NOTETBLLO,Y								;GET TUNE FREQUENCY LOW ADDRESS
	STA NOTELO,X
	LDA NOTETBLHI,Y								;GET TUNE FREQUENCY HIGH ADDRESS
	STA NOTEHI,X
	LDA DURNTBLLO,Y								;GET TUNE DURATION LOW ADDRESS
	STA DURNLO,X
	LDA DURNTBLHI,Y								;GET TUNE DURATION HIGH ADDRESS
	STA DURNHI,X
	LDY TUNCHANNEL
	LDA CTLVOL,X
	STA AUDC0,Y									;STORE THE CONTROL / VOLUME IN THE CHANNEL
	LDA #$01									;SET FREQ, CTL, AND VOL TO BE SET
	STA TUNFRM,X
	JMP TUNNEXT

;	DATA FOR TUNES

;	CNTVOLTBL - HIGH NYBBLE FOR VOICE CONTROL (7654XXXX), AND LOW NYBBLE FOR VOLUME (XXXX3210)
CNTVOLTBL:
	.byte $a7,$a0,$c4,$c7		 	;$A0 on channel 2 to silence channel
	

;	PRIORITY TABLE
PRIRTYTBL:
	.byte $02,$02,$02,$00
	
	
;	CHANNEL TABLE ($00 - $03 ARE VALID)
CHANNLTBL:
	.byte $00,$01,$02,$03			; must set $00 and $01 to use 16-bit combined channel
	

;	DECAY TABLE - DEFINES DECAY COUNT INDEXED BY NOTE DURATION
DECAYTBL:
	.byte $01,$01,$01,$01,$02,$02,$02,$02
	.byte $02,$03,$03,$03,$03,$03,$03,$03
	.byte $04,$04,$04,$04,$04,$04,$04,$04
	.byte $05,$05,$05,$05,$05,$05,$05,$05
	.byte $05,$05,$06,$06,$06,$06,$06,$06
	.byte $06,$06,$06,$06,$07,$07,$07,$07
	.byte $07,$07,$07,$07,$07,$07,$07,$07
	.byte $07,$08,$08,$08,$08,$08,$08,$08

;	FREQUENCY TABLE
NOTETBLHI:
	.byte >(TUNE00),>(TUNE01),>(TUNE02),>(TUNE03)
	

NOTETBLLO:
	.byte <(TUNE00),<(TUNE01),<(TUNE02),<(TUNE03)
	

;	DURATION TABLE
DURNTBLHI:
	.byte >(DURN00),>(DURN01),>(DURN02),>(DURN03)
	

DURNTBLLO:
	.byte <(DURN00),<(DURN01),<(DURN02),<(DURN03)
	

;TEMPOS
T1	=	$03
T2      =       (T1*2)
T3      =       (T1*3)
T4      =       (T1*4)
T5      =       (T1*5)
T6      =       (T1*6)
T7      =       (T1*7)
T8      =       (T1*8)
T9      =       (T1*9)
TA      =       (T1*10)
TB      =       (T1*11)
TC      =       (T1*12)
TD      =       (T1*13)
TE      =       (T1*14)
TF      =       (T1*15)
T0      =       (T1*16)

;A	16264	3F88			
;A#	15351	3BF7			
;B	14489	3899			
;C	13675	356B				OCTAVE 2
;C#	12907	326B			
;D	12182	2F96			
;D#	11498	2CEA			
;E	10852	2A64	
;
;F	10243	2803			
;F#	9668	25C4			
;G	9125	23A5			
;G#	8612	21A4			
;A	8128	1FC0			
;A#	7672	1DF8			
;B	7241	1C49			
;C	6834	1AB2	243	F3		OCTAVE 3
;C#	6450	1932	230	E6	
;D	6088	17C8	217	D9	
;D#	5746	1672	204	CC	
;E	5423	152F	193	C1	
;F	5118	13FE	182	B6	
;F#	4830	12DE	172	AC	
;G	4559	11CF	162	A2	
;G#	4303	10CF	153	99	
;A	4061	0FDD	144	90	

;coin grab sound effect


TUNE00:   
	.byte 0,0,0,0
	.byte 252,254,241,251,254,254,0
	.byte 241,254,254,210,252,226,0
	.byte 252,254,241,251,254,254,0
	.byte 241,254,238,252,226,254,0
	.byte 252,254,241,251,254,254,0
	.byte 241,254,254,210,252,226,0
	.byte 252,254,241,251,254,254,0
	.byte 241,254,238,252,226,254,0
	.byte 252,254,241,252,254,0
	.byte 212,254,241,212,226,0
	.byte 252,254,241,252,254,0
	.byte 212,254,241,210,0
	.byte 252,254,241,251,254,254,0,226
	.byte 252,254,241,251,254,0,241
	.byte 210,249,210,249,210,0,241,238,252,226
	.byte 254,0
	.byte 236,251,251,254,226,252,210,200,249,0
	.byte 236,251,251,254,226,212,252,0,210,0
	.byte 236,251,251,254,226,252,210,200,249,0
	.byte 236,251,251,254,226,212,252,0,210,0
	
	
	.byte -1
		;A	4061	0FDD	144	90	
;A#	3832	0EF8	136	88	
;B	3617	0E21	128	80	
;C	3414	0D56	121	79		OCTAVE 4
;C#	3222	0C96	114	72	
;D	3040	0BE0	108	6C	
;D#	2869	0B35	102	66	
;E	2708	0A94	96	60	
;F	2555	09FB	91	5B	
;F#	2412	096C	85	55	
;G	2276	08E4	81	51	
;G#	2148	0864	76	4C	
;A	2027	07EB	72	48	
;A#	1913	0779	68	44	
;B	1805	070D	64	40	
;C	1703	06A7	60	3C		OCTAVE 5
;C	1703	06A7	60	3C		OCTAVE 5
;C#	1607	0647	57	39	
;D	1517	05ED	53	35	
	
	
DURN00:
	 .byte 60,60,60,60
	.byte 30,24,6,9,15,15,21
	.byte 15,15,15,15,24,24,12
	.byte 30,24,6,9,15,15,21
	.byte 15,15,9,6,9,45,21
	.byte 30,24,6,9,15,15,21
	.byte 15,15,15,15,24,24,12
	.byte 30,24,6,9,15,15,21
	.byte 15,15,9,6,9,45,21
	.byte 24,24,12,24,24,12
	.byte 9,6,15,24,24,42
	.byte 24,24,12,24,24,12
	.byte 9,6,15,30,60
	.byte 30,24,6,9,15,15,15,6
	.byte 9,6,15,24,24,36,6
	.byte 15,15,15,15,15,9,6,9,6,15
	.byte 60,60
	.byte 15,9,6,15,15,9,6,9,6,30
	.byte 15,9,6,15,9,6,15,15,15,15
	.byte 15,9,6,15,15,9,6,9,6,30
	.byte 15,9,6,15,9,6,15,15,15,15
	
	
	.byte 0
	
	
TUNE01:
	.byte 0,0,0,0
	.byte 72,91,121,108,91,91,0
	.byte 121,91,91,60,72,81,0
	.byte 72,91,121,108,91,91,0
	.byte 121,91,68,72,81,91,0
	.byte 72,91,121,108,91,91,0
	.byte 121,91,91,60,72,81,0
	.byte 72,91,121,108,91,91,0
	.byte 121,91,68,72,81,91,0
	.byte 72,91,121,72,91,0
	.byte 76,91,121,76,81,0
	.byte 72,91,121,72,91,0
	.byte 76,91,121,60,0
	.byte 72,91,121,108,91,91,0,81
	.byte 72,91,121,108,91,0,121
	.byte 60,53,60,53,60,0,121,68,72,81
	.byte 91,0
	.byte 136,108,108,91,81,72,60,57,53,0
	.byte 136,108,108,91,81,76,72,0,60,0
	.byte 136,108,108,91,81,72,60,57,53,0
	.byte 136,108,108,91,81,76,72,0,60,0
	
	
	.byte -1
	
	


DURN01:
    .byte 60,60,60,60
	.byte 30,24,6,9,15,15,21
	.byte 15,15,15,15,24,24,12
	.byte 30,24,6,9,15,15,21
	.byte 15,15,9,6,9,45,21
	.byte 30,24,6,9,15,15,21
	.byte 15,15,15,15,24,24,12
	.byte 30,24,6,9,15,15,21
	.byte 15,15,9,6,9,45,21
	.byte 24,24,12,24,24,12
	.byte 9,6,15,24,24,42
	.byte 24,24,12,24,24,12
	.byte 9,6,15,30,60
	.byte 30,24,6,9,15,15,15,6
	.byte 9,6,15,24,24,36,6
	.byte 15,15,15,15,15,9,6,9,6,15
	.byte 60,60
	.byte 15,9,6,15,15,9,6,9,6,30
	.byte 15,9,6,15,9,6,15,15,15,15
	.byte 15,9,6,15,15,9,6,9,6,30
	.byte 15,9,6,15,9,6,15,15,15,15
	
	
	.byte 0
	
	
	
	
	
	
	
	
	

;
;	TUNE 3 - NORMAL 8-BIT CHANNEL

	
TUNE02:
	.byte 133,133,133,133,133,133,124,124,124,124,124,124
	.byte 133,133,133,133,133,133,124,124
	.byte 133,133,133,133,133,133,124,124,124,117,117,117
	.byte 133,133,133,139,139,139,148,148,148,124,124,124
	.byte 133,133,133,133,133,133,124,124,124,117,117,117
	.byte 133,133,133,148,148,148,168,168,168,109,109,109
	.byte 133,133,133,133,133,133,124,124,124,117,117,117
	.byte 133,133,133,139,139,139,148,148,148,124,124,124
	.byte 133,133,133,133,133,133,124,124,124,117,117,117
	.byte 133,133,133,148,148,148,168,168,168,109,109,109
	.byte 124,124,124,124,124,124,133,133,133,133,133,133
	.byte 139,139,139,139,139,139,148,148,148,148,148,148
	.byte 124,124,124,124,124,124,133,133,133,133,133,133
	.byte 139,139,139,139,139,139,148,148,148,148,148,148
	.byte 133,133,133,133,133,133,133,133,133,133,133,133
	.byte 133,133,133,133,133,133,133,133,133,133,133,133
	.byte 133,11
	.byte 133,133,133,133,133,133,133,133,133,133,133,133
	.byte 255,210,168,148,133,148,168,11
	.byte 255,210,168,148,133,14,223,11
	.byte 255,210,168,148,133,148,168,11
	.byte 255,210,168,148,133,14,223,11
	
	.byte -1
	
	
DURN02:
    .byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,45
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,105
	.byte 15,9,6,15,9,6,15,9,6,15,9,6
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	
	
	.byte 0
	
	
	

;
;	TUNE 1 - COMBINED 16-BIT CHANNEL (High order bytes stored in AUDF1)

TUNE03:
   .byte 146,14,173,14,131,14,197,14
   .byte 146,14,173,14,131,137
   .byte 146,14,116,14,110,14,101,14
   .byte 116,14,122,14,131,197,173,155
   .byte 146,14,116,14,110,14,101,14
   .byte 98,197,155,131,146,197,173,155
   .byte 146,14,116,14,110,14,101,14
   .byte 116,14,122,14,131,197,173,155
   .byte 146,14,116,14,110,14,101,14
   .byte 98,197,155,131,146,197,173,155
   .byte 110,101,98,86,98,116,146,122
   .byte 110,98,86,71,65,71,77,98
   .byte 110,116,110,86,71,77,98,116
   .byte 98,86,71,86,110,86,98,71
   .byte 146,14,146,14,167,14,167,14
   .byte 173,14,173,14,182,14,182,14
   .byte 197,14,197,173,155
   .byte 146,14,197,14,146,14,197,14
   .byte 110,116,110,101,98,92,86,122
   .byte 116,110,110,116,146,182,197,182
   .byte 110,116,110,101,98,92,86,122
    .byte 116,110,110,116,146,197,182,14
   
   
	.byte -1
	
		
	
	
	
	
;A	16264	3F88			
;A#	15351	3BF7			
;B	14489	3899			
;C	13675	356B				OCTAVE 2
;C#	12907	326B			
;D	12182	2F96			
;D#	11498	2CEA			
;E	10852	2A64	
;F	10243	2803			
;F#	9668	25C4			
;G	9125	23A5			
;G#	8612	21A4			
;A	8128	1FC0			
;A#	7672	1DF8			
;B	7241	1C49			
;C	6834	1AB2	243	F3		OCTAVE 3
;C#	6450	1932	230	E6	
;D	6088	17C8	217	D9	
;D#	5746	1672	204	CC	
;E	5423	152F	193	C1	
;F	5118	13FE	182	B6	
;F#	4830	12DE	172	AC	
;G	4559	11CF	162	A2	
;G#	4303	10CF	153	99	
;A	4061	0FDD	144	90	
DURN03: ;this table MUST be identical to DURN00:
	
	

    
    .byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,45
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,60,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 15,15,15,15,15,15,15,15
	.byte 0
