;3D Worldrunner Title Music SKCTL demo
;
; AUDCTL=$20  Clock channel 2 at 1.79 Mhz
; SKCTL=$8B (two tone mode)
;
; Channel 0:  $Ax distortion, square wave - modulated from channel 1
; Channel 1:  Silenced ($00) - frequency carrier to channel 0
; Channel 2:  $Cx distortion, clocked at 1.79 Mhz ... sawtooth wave, range A#4 to G6
; Channel 3:  $Ax distortion, no special settings
;
; To play music:
;
; Channel 1 has frequency values taken from standard $Ax 8-bit note table
; Channel 0 plays the same melody as 1, taken from same $Ax note table
;           but transposed up 14 semitones to maintain the pulse width
; Channel 2 has frequency values taken from Distortion 12A table, 1.79 Mhz table
;			formula (freq+1) mod 3 <> 3, (freq+1) mod 3 <> 5
;			$0E = silence (note rest)

	ORG	$2200									;TO $27FF

;	TUNE VARIABLES - $34 BYTES
TUNEAREA		EQU	$2200
TUNESOFF		EQU	TUNEAREA+$0000				;1 BYTE  - FLAG FOR ALL TUNES OFF
TUNNUM			EQU	TUNEAREA+$0001				;1 BYTE  - CURRENT TUNE NUMBER BEING PROCESSED
TUNCHANNEL		EQU	TUNEAREA+$0002				;1 BYTE  - CONVERTED FOR INDEX INTO POKEY CHANNEL REGISTERS
TUNFILLER		EQU	TUNEAREA+$0003				;1 BYTE  - NOT USED YET
TUNON			EQU	TUNEAREA+$0004				;4 BYTES - FLAG FOR TUNE PLAYING BY CHANNEL
NOTELO			EQU	TUNEAREA+$0008				;4 BYTES - INDEX INTO NOTE TABLE LOW
NOTEHI			EQU	TUNEAREA+$000C				;4 BYTES - INDEX INTO NOTE TABLE HI
CTLVOL			EQU	TUNEAREA+$0010				;4 BYTES - CONTROL / VOLUME VALUE BY CHANNEL
TUNINDEX		EQU	TUNEAREA+$0014				;4 BYTES - TUNE NUMBER BY CHANNEL
TUNFRM			EQU	TUNEAREA+$0018				;4 BYTES - NUMBER OF FRAMES (DURATION COUNT)
TUNPRIOR		EQU	TUNEAREA+$001C				;4 BYTES - TUNE PRIORITY BY CHANNEL
DURNLO			EQU	TUNEAREA+$0020				;4 BYTES - INDEX INTO DURATION TABLE LOW
DURNHI			EQU	TUNEAREA+$0024				;4 BYTES - INDEX INTO DURATION TABLE HI
DCYSTOR			EQU	TUNEAREA+$0028				;4 BYTES - FOR NOTE DECAY BY CHANNEL
FREQCNT			EQU	TUNEAREA+$002C				;4 BYTES - FOR NOTE DECAY BY CHANNEL
CTLSAV			EQU	TUNEAREA+$0030				;4 BYTES - TO SAVE THE CONTROL VALUE

	org $2240

;	SOUND -------------------------------------------------------------------------------------------------------------------->

;	TUNES - THESE ROUTINES HANDLE ALL OF THE SOUNDS

;	RESET POKEY CHIP
RSTPOKEY:
	LDX #$0F 
	LDA #$00
RSTLP:
	STA AUDF0,X									;CLEAR POKEY REGISTERS
	DEX 
	BPL RSTLP 
	LDA #$03
	STA SKCTL	;S									;TURN IT ON
	RTS

;	TURN OFF ALL SOUNDS
STOPTUN
	LDA #$00
	STA AUDC0
	STA AUDC1
	STA AUDC2
	STA AUDC3
	LDA #$01
	STA TUNESOFF
	RTS

;	TURN ON ALL SOUNDS
STARTTUN
	LDA #$00
	STA TUNESOFF
	RTS

;	THIS ROUTINE ERASES ALL TUNES
;	X AND Y ARE PRESERVED
CLEARTUN
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDX #$03
CTLOOP
	JSR ENDTUNE									;ERASE CURRENT TUNE
	DEX
	BPL CTLOOP
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;	ROUTINE TO KILL A PARTICULAR TUNE - IF IT IS RUNNING
;	INPUT: TUNE NUMBER IN A
;	X AND Y ARE PRESERVED
KILLTUNE
	STA TUNNUM									;SAVE IT
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDX #$03									;CHECK ALL CHANNELS
KTLOOP
	LDA TUNON,X									;SEE IF CHANNEL ON
	BEQ KTNEXT
	LDA TUNINDEX,X								;SEE IF HAS TUNE TO BE KILLED
	CMP TUNNUM
	BNE KTNEXT
	JSR ENDTUNE									;ERASE IT
KTNEXT
	DEX
	BPL KTLOOP
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;	THIS ROUTINE CLEARS OUT A TUNE CHANNEL
;	INPUT: X IS CHANNEL
ENDTUNE
	LDA #$00
	STA TUNON,X									;INDICATE CHANNEL CLEAR
	STA TUNINDEX,X								;CLEAR TUNE INDEX
	STA DCYSTOR,X
	STA FREQCNT,X
	RTS

;	THIS ROUTINE ENTERS A TUNE INTO ONE OF THE SOUND CHANNELS IF IT CAN
;	INPUT:  TUNE NUMBER IN A
;	X AND Y ARE PRESERVED
DOTUNE
	STA TUNNUM									;SAVE IT
	;LDA AUTOPLAY								;IF IN AUTOPLAY - NO SOUND
	;BEQ DTCONT
	;RTS
DTCONT
	TXA											;STACK REGISTERS
	PHA
	TYA
	PHA
	LDY TUNNUM									;SEE IF WE CAN PUT IT IN
	LDX CHANNLTBL,Y								;GET WHAT CHANNEL TO TRY TO PUT IT IN
	LDA TUNON,X									;SEE IF CHANNEL OPEN
	BEQ DTDOIT
	LDA PRIRTYTBL,Y								;SEE IF WE CAN BUMP CHANNEL
	CMP TUNPRIOR,X
	BMI DTOUT
DTDOIT
	LDA TUNNUM
	TAY											;PUT TUNE IN Y
	STA TUNINDEX,X								;SET THE TUNE INDEX
	LDA #$00									;TURN TUNE OFF WHILE CHANGING IT
	STA TUNON,X
	LDA CNTVOLTBL,Y								;GET TUNE CONTROL / VOLUME
	STA CTLVOL,X
	STA CTLSAV,X								;USED TO RESTORE AFTER DECAY
	LDA NOTETBLLO,Y								;GET TUNE FREQUENCY LOW ADDRESS
	STA NOTELO,X
	LDA NOTETBLHI,Y								;GET TUNE FREQUENCY HIGH ADDRESS
	STA NOTEHI,X
	LDA DURNTBLLO,Y								;GET TUNE DURATION LOW ADDRESS
	STA DURNLO,X
	LDA DURNTBLHI,Y								;GET TUNE DURATION HIGH ADDRESS
	STA DURNHI,X
	LDA PRIRTYTBL,Y								;SET PRIORITY
	STA TUNPRIOR,X
	LDA #$01									;SET FREQ, CTL, AND VOL TO BE SET
	STA TUNFRM,X
	STA TUNON,X									;AND TURN THE TUNE ON!
DTOUT
	PLA											;UNSTACK REGISTERS
	TAY
	PLA
	TAX
	RTS

;  THIS ROUTINE IS CALLED EVERY VBLANK TO TAKE CARE OF TUNES
;  REGISTERS ARE NOT SAVED
TUNER
	LDX #$03									;FOUR TUNES CHANNELS, START WITH LAST
	LDA TUNESOFF
	BEQ TUNLOOP
	RTS
TUNLOOP
	TXA
	ASL
	STA TUNCHANNEL								;CHANNELS ARE OFFSET 0, 2, 4, 6 IN THE POKEY
	TAY
	LDA TUNON,X
	BNE TUNBODY
	STA AUDC0,Y									;CHANNEL OFF - MAKE SURE VOLUME OFF
	JMP TUNNEXT
TUNBODY
	DEC TUNFRM,X								;SEE IF WE'RE DONE WITH THIS SOUND
	BEQ TUNFRMFRQ								;YES - GET NEXT NOTE / DURATION
	DEC FREQCNT,X                               ;REDUCE THE NUMBER OF FRAMES UNTIL NEXT DECAY
	BEQ DEC_VOLUME
	JMP TUNNEXT                                 ;IF WE AREN'T AT ZERO YET, DON'T DECAY

DEC_VOLUME
	LDA DCYSTOR,X                               ;RESET THE DECAY FOR THE NEXT COUNT
	STA FREQCNT,X

	LDA CTLVOL,X                                ;IF VOLUME ALREADY 0 DO NOT DECREMENT
	AND #$0F
	BEQ TUNNEXT
	
	DEC CTLVOL,X                                ;DECREMENT THE VOLUME
	LDA CTLVOL,X
	LDY TUNCHANNEL
	;AND MUTEMASK,Y
	STA AUDC0,Y
	JMP TUNNEXT                                 ;GO TO NEXT CHANNEL
TUNFRMFRQ
	LDA DURNLO,X								;GET THE CURRENT DURATION
	STA SOUNDZP
	LDA DURNHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	BEQ TUNEND									;$00 IN DURATION MEANS TUNE IS OVER
	STA TUNFRM,X
	TAY
	LDA DECAYTBL,Y								;GET THE CURRENT DECAY VALUE INDEXED BY NOTE
	STA DCYSTOR,X								;STORE IT HERE TO REFRESH THE COUNTER FOR THE NEXT DECAY
	STA FREQCNT,X								;ALSO STORE IT HERE FOR TUNER
	LDY TUNCHANNEL
	LDA CTLSAV,X
	STA CTLVOL,X	;RESTORE THE ORIGINAL CONTROL AND VOLUME FOR NEXT NOTE
	AND #$0F
	BEQ SKIPWRITEZERO
	LDA CTLSAV,X
	STA AUDC0,Y
SKIPWRITEZERO
	LDA NOTELO,X								;GET THE CURRENT FREQUENCY
	STA SOUNDZP
	LDA NOTEHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	LDY TUNCHANNEL
	STA AUDF0,Y
	INC NOTELO,X
	BNE TUNNEXTNOTE
	INC NOTEHI,X
TUNNEXTNOTE
	INC DURNLO,X
	BNE TUNNEXT
	INC DURNHI,X
TUNNEXT
	DEX
	CPX #$00
	BMI TUNEXIT
	JMP TUNLOOP
TUNEXIT
	RTS

TUNEND
	LDA NOTELO,X								;SEE IF WE SHOULD REPEAT
	STA SOUNDZP
	LDA NOTEHI,X
	STA SOUNDZP+1
	LDY #$00
	LDA (SOUNDZP),Y
	BMI TUNRESTART
	JSR ENDTUNE
	JMP TUNNEXT
TUNRESTART
	LDA TUNINDEX,X								;GET TUNE NUMBER
	TAY
	LDA CNTVOLTBL,Y								;GET TUNE CONTROL / VOLUME
	STA CTLVOL,X
	STA CTLSAV,X								;USED TO RESTORE AFTER DECAY
	LDA NOTETBLLO,Y								;GET TUNE FREQUENCY LOW ADDRESS
	STA NOTELO,X
	LDA NOTETBLHI,Y								;GET TUNE FREQUENCY HIGH ADDRESS
	STA NOTEHI,X
	LDA DURNTBLLO,Y								;GET TUNE DURATION LOW ADDRESS
	STA DURNLO,X
	LDA DURNTBLHI,Y								;GET TUNE DURATION HIGH ADDRESS
	STA DURNHI,X
	LDY TUNCHANNEL
	LDA CTLVOL,X
	STA AUDC0,Y									;STORE THE CONTROL / VOLUME IN THE CHANNEL
	LDA #$01									;SET FREQ, CTL, AND VOL TO BE SET
	STA TUNFRM,X
	JMP TUNNEXT

;	DATA FOR TUNES

;	CNTVOLTBL - HIGH NYBBLE FOR VOICE CONTROL (7654XXXX), AND LOW NYBBLE FOR VOLUME (XXXX3210)
CNTVOLTBL:
	
	.byte $a7,$00,$c5,$A7
	

;	PRIORITY TABLE
PRIRTYTBL:
	.byte $02,$02,$02,$00
	
	
;	CHANNEL TABLE ($00 - $03 ARE VALID)
CHANNLTBL:
	.byte $00,$01,$02,$03			
	

;	DECAY TABLE - DEFINES DECAY COUNT INDEXED BY NOTE DURATION
DECAYTBL:
	.byte $01,$01,$01,$01,$02,$02,$02,$02
	.byte $02,$03,$03,$03,$03,$03,$03,$03
	.byte $04,$04,$04,$04,$04,$04,$04,$04
	.byte $05,$05,$05,$05,$05,$05,$05,$05
	.byte $05,$05,$06,$06,$06,$06,$06,$06
	.byte $06,$06,$06,$06,$07,$07,$07,$07
	.byte $07,$07,$07,$07,$07,$07,$07,$07
	.byte $07,$08,$08,$08,$08,$08,$08,$08

;	FREQUENCY TABLE
NOTETBLHI:
	.byte >(TUNE00),>(TUNE01),>(TUNE02),>(TUNE03)
	

NOTETBLLO:
	.byte <(TUNE00),<(TUNE01),<(TUNE02),<(TUNE03)
	

;	DURATION TABLE
DURNTBLHI:
	.byte >(DURN00),>(DURN01),>(DURN02),>(DURN03)
	
DURNTBLLO:
	.byte <(DURN00),<(DURN01),<(DURN02),<(DURN03)
	

;TEMPOS
T1	=	$03
T2      =       (T1*2)
T3      =       (T1*3)
T4      =       (T1*4)
T5      =       (T1*5)
T6      =       (T1*6)
T7      =       (T1*7)
T8      =       (T1*8)
T9      =       (T1*9)
TA      =       (T1*10)
TB      =       (T1*11)
TC      =       (T1*12)
TD      =       (T1*13)
TE      =       (T1*14)
TF      =       (T1*15)
T0      =       (T1*16)


; CHANNEL 0 - $Ax setting, plays melody transposed up 17 semitones 


TUNE00:   
	.byte 14,15,17,19,22,23,26,30
	.byte 17,0,15,14,15,17,15,14,0
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,30,40,30
	.byte 35,31,30,23,26,31,40,0
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,31,30,23
	.byte 26,31,40,30,0
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,30,40,30
	.byte 35,31,30,23,26,31,40,0
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,31,30,23
	.byte 19,22,23,26,30,0
	.byte 23,22,23,22,23,26,30,31,30,26
	.byte 23,22,23,26,23,26,30,31,35,31,30,23
	.byte 26,23,26,23,26,30,31,35,31,30
	.byte 26,23,26,30,26,30,31,30,35,31,40,0
	.byte 23,22,23,22,23,26,30,31,30,26
	.byte 23,22,23,26,23,26,30,31,35,31,30,23
	.byte 26,23,26,23,26,30,31,35,31,30
	.byte 26,23,21,19,19,19,0
	
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,30,40,30
	.byte 35,31,30,23,26,31,40,0
	.byte 40,26,26,23,22,23,26
	.byte 30,26,23,26,31,40
	.byte 35,30,40,30,35,31,30,23
	.byte 19,22,23,26,30,0
	
	
	.byte -1
	

	
	
DURN00:
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,4,3,3,5,5,10,30
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 20,10,10,20,20
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,20,20,10,10,10,10
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,10,10,10,10,20,20
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,20,20,10,10,10,10
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 40,20,20,20,20,20,20
	
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	
	.byte 0
	
; CHANNEL 1 - Silenced ($00) but plays the main melody.  Frequency carrier for channel 0
	
	
TUNE01:
	
	.byte 39,42,47,53,60,64,72,81
	.byte 47,0,42,39,42,47,42,39,0
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,108,81
	.byte 96,85,81,64,72,85,108,0
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,81,64
	.byte 72,85,108,81,0
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,108,81
	.byte 96,85,81,64,72,85,108,0
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,81,64
	.byte 53,60,64,72,81,0
	.byte 64,60,64,60,64,72,81,85,81,72
	.byte 64,60,64,72,64,72,81,85,96,85,81,64
	.byte 72,64,72,64,72,81,85,96,85,81
	.byte 72,64,72,81,72,81,85,81,96,85,108,0
	.byte 64,60,64,60,64,72,81,85,81,72
	.byte 64,60,64,72,64,72,81,85,96,85,81,64
	.byte 72,64,72,64,72,81,85,96,85,81
	.byte 72,64,57,53,53,53,0
	
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,108,81
	.byte 96,85,81,64,72,85,108,0
	.byte 108,72,72,64,60,64,72
	.byte 81,72,64,72,85,108
	.byte 96,81,108,81,96,85,81,64
	.byte 53,60,64,72,81,0
	
	
	
	.byte -1
	
	
	


DURN01:
    .byte 10,10,10,10,10,10,10,10
	.byte 10,10,4,3,3,5,5,10,30
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 20,10,10,20,20
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,20,20,10,10,10,10
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,10,10,10,10,20,20
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 20,10,10,20,10,10,20,20,10,10,10,10
	.byte 30,10,30,10,20,20,10,10,10,10
	.byte 40,20,20,20,20,20,20
	
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	
	
	
	
	.byte 0
	
	
	
	
; Channel 2 - harmony channel.  Distortion $Cx (12a), but clocked at 1.79 Mhz, frequency range A#4 to G6


	
TUNE02:
	.byte 69,73,84,97,109,117,133,148
	.byte 84,14,73,69,43,84,73,69,11
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,177,240,177
	.byte 223,199,177,148,157,199,240,11
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,199,177,148
	.byte 177,199,240,199,11
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,177,240,177
	.byte 223,199,177,148,157,199,240,11
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,199,177,148
	.byte 133,148,157,177,199,11
	.byte 157,187,177,240,187,157,177,240,177,240
	.byte 177,210,199,240,210,177,199,210,199,177
	.byte 157,187,177,240,187,157,177,240,177,240
	.byte 177,210,199,240,210,177,199,199,199,11
	
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,177,240,177
	.byte 223,199,177,148,157,199,240,11
	.byte 199,157,157,148,133,148,157
	.byte 199,157,148,157,199,240
	.byte 223,177,240,177,223,199,177,148
	.byte 133,148,157,177,199,11
	
	.byte -1
	
	
DURN02:
   .byte 10,10,10,10,10,10,10,10
	.byte 10,10,4,3,3,5,5,10,30
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 20,10,10,20,20
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	.byte 40,40,40,40,40,40,20,20,20,20
	.byte 40,40,40,40,40,40,20,20,20,20
	.byte 40,40,40,40,40,40,20,20,20,20
	.byte 40,40,40,40,40,40,20,20,20,20
	
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,20,10,10
	.byte 20,10,10,10,10,20
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	
	.byte 0
	
	
	
; CHANNEL 3 - Normal 8-bit channel ($Ax) square wave - bass


TUNE03:
   .byte 162,144,128,121,108,96,85,81
	.byte 121,0,108,0,162,0
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,243,96,255,108
	.byte 243,96,193,96,217,85,217,85
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,243,96,255,108
	.byte 217,85,217,85,162,172,193,204
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,243,96,255,108
	.byte 243,96,193,96,217,85,217,85
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,193,121,217,128
	.byte 217,217,193,172,162,162,144,136
	.byte 255,128,0,128,0,128,255,128
	.byte 193,96,0,96,0,96,193,96
	.byte 255,128,0,128,0,128,255,128
	.byte 193,96,0,96,0,96,193,96
	.byte 144,72,0,72,0,72,144,72
	.byte 217,108,0,108,0,108,217,108
	.byte 144,72,0,72,0,72,144,72
	.byte 217,108,0,108,0,108,217,108
	.byte 255,128,0,128,0,128,255,128
	.byte 193,96,0,96,0,96,193,96
	.byte 255,128,0,128,0,128,255,128
	.byte 193,96,0,96,0,96,193,96
	.byte 144,72,0,72,0,72,144,72
	.byte 217,108,0,108,0,108,217,108
	.byte 144,72,0,72,0,72,144,72
	.byte 40,42,47,42,53,121,128,144,162,172,193
	
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,243,96,255,108
	.byte 243,96,193,96,217,85,217,85
	.byte 217,144,144,144,217,144,144,144
	.byte 162,128,128,128,217,144,144,144
	.byte 243,96,255,108,243,96,255,108
	.byte 217,85,217,85,162,172,193,204
	
	.byte -1
	
		
	
	
	
	

DURN03: 
	
	

    
    .byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,30
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,5,5,5,5,5,5
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	.byte 10,10,10,10,10,10,10,10
	
	
	
	
	
	
	.byte 0

